@@ -5,4 +5,4 @@ from __init__ import configuration
 
 get_logs_client = get_sent_sms_logs(configuration)
 response = get_logs_client.execute({"limit": 10})
-print(response)
+print(unicode(response))
